package com.ynet.life.loaf;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.gene.data.IndexedCollection;
import com.ynet.gene.data.KeyedCollection;
import com.ynet.life.base.LifeDBAccess;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.loaf.jdbc.DataTypeConfig;
import com.ynet.life.loaf.jdbc.LoafPreparedData;
import com.ynet.life.loaf.jdbc.LoafPreparedQuery;
import com.ynet.life.loaf.jdbc.LoafQueryCondition;
import com.ynet.life.loaf.jdbc.LoafQueryFactory;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;

/* loaded from: com_ynet_life_loaf.jar:com/ynet/life/loaf/DataMappingProvider.class */
public class DataMappingProvider {
    protected static Map TABLE_CONFIG_MAP = null;
    private static final TranFailException EXCEPTION_DATA_NOT_FOUND = new TranFailException("EBLN5001", "要查询的记录不存在");

    protected DataMappingProvider() {
    }

    public static void initTableConfig(String filePathName) throws TranFailException {
        TABLE_CONFIG_MAP = TableConfig.initFormFile(filePathName);
    }

    public static int getOpType(String input) {
        int result = Integer.parseInt(input);
        switch (result) {
            case LoafConstants.OP_TYPE_ADD /* 1 */:
            case LoafConstants.OP_TYPE_DELETE /* 2 */:
            case LoafConstants.OP_TYPE_UPDATE /* 3 */:
            case LoafConstants.OP_TYPE_RENEW /* 4 */:
                return result;
            default:
                Trace.logWarning("LOAF", "错误的操作类型：".concat(String.valueOf(input)));
                return 1;
        }
    }

    public static void doTableOperation(Connection connection, TableConfig tableConfig, int opType, Map context) throws TranFailException {
        List inputList = new LinkedList();
        String resultSql = getPrepareSQLAndData(tableConfig, opType, context, inputList, false);
        if (resultSql.length() > 0 && !resultSql.endsWith(" SET ")) {
            PreparedStatement statement = null;
            try {
                try {
                    Trace.logDebug("LOAF", "执行SQL--->".concat(String.valueOf(resultSql)));
                    Trace.logDebug("LOAF", "输入参数列表--->".concat(String.valueOf(inputList)));
                    statement = connection.prepareStatement(resultSql.toString());
                    int inputSize = inputList.size();
                    for (int i = 1; i <= inputSize; i++) {
                        ((LoafPreparedData) inputList.get(i - 1)).fillStatement(statement, i);
                    }
                    int updateCount = statement.executeUpdate();
                    if (4 == opType && updateCount == 0) {
                        doTableOperation(connection, tableConfig, 1, context);
                    }
                    if (statement != null) {
                        try {
                            statement.close();
                        } catch (SQLException ex) {
                            Trace.logWarning("LifeJDBC", "JDBC对象关闭异常", ex);
                        }
                    }
                } catch (SQLException se) {
                    Trace.logError("LOAF", se.getMessage(), se);
                    throw new TranFailException(se);
                }
            } catch (Throwable th) {
                if (statement != null) {
                    try {
                        statement.close();
                    } catch (SQLException ex2) {
                        Trace.logWarning("LifeJDBC", "JDBC对象关闭异常", ex2);
                    }
                }
                throw th;
            }
        }
    }

    public static void doTableBatchOperation(Connection connection, TableConfig tableConfig, int opType, IndexedCollection icoll) throws TranFailException {
        if (opType == 1 || opType == 2) {
            doBatchOperation(connection, tableConfig, opType, icoll);
            return;
        }
        Map opTypeDataMap = new HashMap();
        for (int i = 0; i < icoll.size(); i++) {
            KeyedCollection kcoll = icoll.getElementAt(i);
            String str = (String) kcoll.get(LoafConstants.OP_TYPE_NAME);
            String subOpTypeStr = str;
            if (str == null) {
                subOpTypeStr = String.valueOf(opType);
            }
            IndexedCollection indexedCollection = (IndexedCollection) opTypeDataMap.get(subOpTypeStr);
            IndexedCollection subIcoll = indexedCollection;
            if (indexedCollection == null) {
                subIcoll = new IndexedCollection();
                opTypeDataMap.put(subOpTypeStr, subIcoll);
            }
            subIcoll.add(kcoll);
        }
        for (Map.Entry entry : opTypeDataMap.entrySet()) {
            int subOpType = Integer.parseInt((String) entry.getKey());
            IndexedCollection subIcoll2 = (IndexedCollection) entry.getValue();
            if (subOpType == 1 || subOpType == 2) {
                doBatchOperation(connection, tableConfig, subOpType, subIcoll2);
            } else if (subOpType == 3 || subOpType == 4) {
                for (int j = 0; j < subIcoll2.size(); j++) {
                    doTableOperation(connection, tableConfig, subOpType, subIcoll2.getElementAt(j));
                }
            }
        }
    }

    public static void doBatchOperation(Connection connection, TableConfig tableConfig, int opType, IndexedCollection icoll) throws TranFailException {
        List inputList = new LinkedList();
        PreparedStatement statement = null;
        for (int i = 0; i < icoll.size(); i++) {
            try {
                try {
                    KeyedCollection kcoll = icoll.getElementAt(i);
                    if (i == 0) {
                        String resultSql = getPrepareSQLAndData(tableConfig, opType, kcoll, inputList, false);
                        PreparedStatement prepareStatement = connection.prepareStatement(resultSql.toString());
                        statement = prepareStatement;
                        if (prepareStatement == null) {
                            Trace.logError("LifeJDBC", "数据库异常");
                            throw new TranFailException("EBLN0036", "数据库异常");
                        }
                        Trace.logDebug("LOAF", "执行批量SQL--->".concat(String.valueOf(resultSql)));
                    } else {
                        getPrepareSQLAndData(tableConfig, opType, kcoll, inputList, true);
                    }
                    Trace.logDebug("LOAF", "输入参数列表--->".concat(String.valueOf(inputList)));
                    int inputSize = inputList.size();
                    for (int j = 1; j <= inputSize; j++) {
                        ((LoafPreparedData) inputList.get(j - 1)).fillStatement(statement, j);
                    }
                    inputList.clear();
                    statement.addBatch();
                } catch (SQLException se) {
                    Trace.logError("LOAF", se.getMessage(), se);
                    throw new TranFailException(se);
                }
            } catch (Throwable th) {
                if (statement != null) {
                    try {
                        statement.close();
                    } catch (SQLException ex) {
                        Trace.logWarning("LifeJDBC", "JDBC对象关闭异常", ex);
                    }
                }
                throw th;
            }
        }
        statement.executeBatch();
        if (statement != null) {
            try {
                statement.close();
            } catch (SQLException ex2) {
                Trace.logWarning("LifeJDBC", "JDBC对象关闭异常", ex2);
            }
        }
    }

    public static String getPrepareSQLAndData(TableConfig tableConfig, int opType, Map context, List inputList, boolean prepareDataOnly) throws TranFailException {
        Object contextFieldValue;
        StringBuffer resultSql = new StringBuffer();
        String tableName = tableConfig.getTableName();
        Map tableToDataHashMap = tableConfig.getTableFieldToDataHashMap();
        if (1 == opType) {
            if (!prepareDataOnly) {
                resultSql.append("INSERT INTO ").append(tableName).append('(');
            }
            StringBuffer insertTableFields = new StringBuffer();
            StringBuffer insertValues = new StringBuffer();
            for (String tableFieldName : tableToDataHashMap.keySet()) {
                if (tableConfig.isJoinedPK(tableFieldName)) {
                    contextFieldValue = tableConfig.getJoinedValue(tableFieldName, context);
                } else {
                    String contextFieldName = (String) tableToDataHashMap.get(tableFieldName);
                    contextFieldValue = context.get(contextFieldName);
                }
                if (contextFieldValue != null && contextFieldValue.toString().length() > 0) {
                    if (!prepareDataOnly) {
                        insertTableFields.append(tableFieldName).append(',');
                        insertValues.append("?,");
                    }
                    inputList.add(DataTypeConfig.getData(tableName, tableFieldName, contextFieldValue));
                }
            }
            if (!prepareDataOnly) {
                LoafTools.removeLastComma(insertTableFields);
                LoafTools.removeLastComma(insertValues);
                if (insertTableFields.length() > 0) {
                    resultSql.append(insertTableFields).append(")VALUES(").append(insertValues).append(')');
                }
            }
        } else {
            LoafQueryCondition condition = new LoafQueryCondition(tableConfig, context);
            inputList.addAll(condition.getInputList());
            if (2 == opType && !prepareDataOnly) {
                resultSql.append("DELETE FROM ").append(tableName).append(" WHERE ").append(condition.getCondition());
            } else if (3 == opType || 4 == opType) {
                boolean hasChange = false;
                if (!prepareDataOnly) {
                    resultSql.append("UPDATE ").append(tableName).append(" SET ");
                }
                LinkedList linkedList = new LinkedList();
                for (String tableFieldName2 : tableToDataHashMap.keySet()) {
                    if (!tableConfig.getPrimaryKeyHashMap().contains(tableFieldName2)) {
                        String contextFieldName2 = (String) tableToDataHashMap.get(tableFieldName2);
                        String contextFieldValue2 = (String) context.get(contextFieldName2);
                        if (contextFieldValue2 != null) {
                            if (!prepareDataOnly) {
                                resultSql.append(tableFieldName2).append("=?,");
                            }
                            linkedList.add(DataTypeConfig.getData(tableConfig.getTableName(), tableFieldName2, contextFieldValue2));
                            hasChange = true;
                        }
                    }
                }
                if (hasChange) {
                    inputList.addAll(0, linkedList);
                    if (!prepareDataOnly) {
                        LoafTools.removeLastComma(resultSql);
                        resultSql.append(" WHERE ").append(condition.getCondition());
                    }
                }
            }
        }
        return resultSql.toString();
    }

    public static void fillTableDataIntoContext(Connection connection, String businessCode, Map context) throws TranFailException, SQLException {
        fillTableDataIntoContext(connection, businessCode, context, context);
    }

    public static void fillTableDataIntoContext(Connection connection, String businessCode, Map inputContext, Map outputContext) throws TranFailException, SQLException {
        PreparedStatement statement = null;
        ResultSet resultSet = null;
        TableConfig config = getTableConfig(businessCode);
        LoafPreparedQuery query = getQueryUsingPK(config, inputContext);
        Trace.logDebug("LOAF", "查询SQL-->".concat(String.valueOf(query)));
        try {
            statement = query.getPreparedStatement(connection);
            resultSet = statement.executeQuery();
            if (resultSet.next()) {
                Map tableFieldToDataHashMap = getTableConfig(businessCode).getTableFieldToDataHashMap();
                for (String tableField : tableFieldToDataHashMap.keySet()) {
                    String contextFieldName = (String) tableFieldToDataHashMap.get(tableField);
                    LoafPreparedData resultData = DataTypeConfig.getData(config.getTableName(), tableField);
                    resultData.fetchResult(resultSet, tableField);
                    outputContext.put(contextFieldName, resultData.getDataValue());
                }
                return;
            }
            Trace.logError("LOAF", EXCEPTION_DATA_NOT_FOUND.getShowMessage(), EXCEPTION_DATA_NOT_FOUND);
            throw EXCEPTION_DATA_NOT_FOUND;
        } finally {
            LifeDBAccess.cleanResources(statement, resultSet);
        }
    }

    public static void fillShowDataIntoContext(Connection connection, TableConfig tableConfig, Map context) throws SQLException, TranFailException {
        List showBusinessList = tableConfig.getShowBusinessList();
        for (int i = 0; i < showBusinessList.size(); i++) {
            String subBusinessCode = (String) showBusinessList.get(i);
            fillTableDataIntoContext(connection, subBusinessCode, context);
        }
    }

    public static TableConfig getTableConfig(String businessCode) throws TranFailException {
        TableConfig tableConfig = (TableConfig) TABLE_CONFIG_MAP.get(businessCode);
        if (tableConfig == null) {
            Trace.logError("LOAF", "LOAF代码[" + businessCode + "]未定义");
            throw new TranFailException("EBLN0000", "LOAF代码[" + businessCode + "]未定义");
        }
        return tableConfig;
    }

    public static void queryResultSetByPage(Connection connection, TableConfig tableConfig, Context context, IndexedCollection input, int beginPos, int showNum, String totalNumFieldName, String sortParam) throws TranFailException {
        com.ynet.life.loaf.jdbc.LoafQueryInterface query = LoafQueryFactory.createQueryEntity(context, tableConfig, input.getDataElement(), sortParam);
        List inputList = getQueryInputList(tableConfig, context);
        Trace.logDebug("LOAF", "查询SQL--->".concat(String.valueOf(query)));
        Trace.logDebug("LOAF", "输入参数列表--->".concat(String.valueOf(inputList)));
        int totalNum = query.getCount(connection, inputList);
        if (totalNum > 0) {
            PreparedStatement ps = null;
            ResultSet resultSet = null;
            try {
                try {
                    PreparedStatement queryByPageStatement = query.getQueryByPageStatement(connection, inputList, beginPos, showNum);
                    ps = queryByPageStatement;
                    resultSet = queryByPageStatement.executeQuery();
                    LoafTools.fillResultIntoIcoll(tableConfig, resultSet, input);
                    Trace.logDebug("LOAF", "查询结果--->\n".concat(String.valueOf(input)));
                    LifeDBAccess.cleanResources(ps, resultSet);
                } catch (SQLException se) {
                    Trace.logError("LOAF", se.getMessage(), se);
                    throw new TranFailException("EBLN0000", se);
                }
            } catch (Throwable th) {
                LifeDBAccess.cleanResources(ps, resultSet);
                throw th;
            }
        }
        try {
            context.setDataValue(totalNumFieldName, String.valueOf(totalNum));
        } catch (GENEException empe) {
            Trace.logError("LOAF", empe.getMessage(), empe);
            throw new TranFailException("EBLN0000", empe);
        }
    }

    public static LoafPreparedQuery getQueryUsingPK(TableConfig tableConfig, Map context) {
        LoafQueryCondition condition = new LoafQueryCondition(tableConfig, context);
        return new LoafPreparedQuery(tableConfig, condition, (String) null);
    }

    public static LoafPreparedQuery getQueryUsingCondition(TableConfig tableConfig, String conditionSQL) {
        LoafQueryCondition condition = new LoafQueryCondition(conditionSQL);
        return new LoafPreparedQuery(tableConfig, condition, (String) null);
    }

    public static String getPKFromContext(String businessCode, Map context) throws TranFailException {
        TableConfig tableConfig = getTableConfig(businessCode);
        return new LoafQueryCondition(tableConfig, context).toString();
    }

    public static String getPKFromKcoll(TableConfig config, String tableKey, KeyedCollection kcoll) {
        boolean isJoinedKey = config.isJoinedPK(tableKey);
        StringBuffer result = new StringBuffer();
        if (isJoinedKey) {
            List array = config.getJoinedPKList(tableKey);
            int size = array.size();
            for (int i = 0; i < size; i++) {
                String keyFieldName = (String) array.get(i);
                try {
                    result.append((String) kcoll.getDataValue(keyFieldName));
                } catch (GENEException ex) {
                    Trace.logWarning("LOAF", "无法找到数据", ex);
                }
            }
        } else {
            try {
                result.append((String) kcoll.getDataValue((String) config.getTableFieldToDataHashMap().get(tableKey)));
            } catch (GENEException ex2) {
                Trace.logWarning("LOAF", "无法找到数据", ex2);
            }
        }
        return result.toString();
    }

    public static List getQueryInputList(TableConfig tableConfig, Map context) {
        List inputList = new ArrayList();
        for (String dataFieldName : tableConfig.getDataToTableFieldHashMap().keySet()) {
            if (context.containsKey(dataFieldName)) {
                String dataFieldValue = (String) context.get(dataFieldName);
                if ((tableConfig.getSearchKeySet().size() > 0 && tableConfig.getSearchKeySet().contains(dataFieldName)) || (tableConfig.getSearchKeySet().size() == 0 && dataFieldValue != null && dataFieldValue.length() > 0)) {
                    inputList.add(dataFieldValue);
                }
            }
        }
        return inputList;
    }
}
